from typing import List, Union

import pandas as pd


class SGS:
    """ Consulta séries temporais no SGS - Sistema Gerenciador de Séries
        Temporais do Banco Central do Brasil """

    def __init__(self) -> None:
        pass

    def read_from_api(
        self, codigo_serie: int, data_inicio: str, data_fim: str
    ) -> pd.DataFrame:
        url = (
            "http://api.bcb.gov.br/dados/serie/bcdata.sgs.{}"
            "/dados?formato=csv&dataInicial={}&dataFinal={}"
        )
        df = pd.read_csv(
            url.format(codigo_serie, data_inicio, data_fim),
            index_col="data",
            parse_dates=True,
            dayfirst=True,
            sep=";",
            names=["data", codigo_serie],
            header=0,
        )
        del df.index.name
        return df

    def get_valores_series(
        self,
        codigo_serie: Union[int, List],
        data_inicio: str,
        data_fim: str
    ) -> pd.DataFrame:
        """ Solicita uma série temporal ao SGS.

            Parâmetros
            ----------

            * codigo_serie(int): código da série
            * data_inicio(str): data de inicio no format dd/mm/yyyy
            * data_fim(str): data de fim no format dd/mm/yyyy

            Retorna dataframe contendo os valores da série temporal.
        """
        if not isinstance(codigo_serie, (list, tuple)):
            codigos = [codigo_serie]
        else:
            codigos = codigo_serie

        series = []
        for cod in codigos:
            df = self.read_from_api(cod, data_inicio, data_fim)
            series.append(df)

        return pd.concat(series, axis=1)



from setuptools import setup, find_packages

__version__ = '1.30.1'

with open('README.rst', 'r', encoding='utf-8') as f:
    readme = f.read()


requirements = [
    'defusedxml>=0.6.0',
    'jinja2>=2.9.5',
    'lxml>=4',
    'pandas>=0.22.0',
    'requests>=2.18.4'
]

dev_requirements = [
    "bandit==1.6.0",
    "pytest==4.6.2",
    "pytest-cov==2.7.1",
    "pytest-pep8==1.0.6",
    "pytest-mypy==0.3.2"
]

setup(
    name='sgs',
    packages=['sgs'],
    python_requires=">=3.5",
    install_requires=requirements,
    extras_require={
        'dev': dev_requirements
    },
    version=__version__,
    description=('Python wrapper para o webservice do SGS - '
                 'Sistema Gerenciador de Series Temporais do '
                 'Banco Central do Brasil.'),
    license="MIT",
    long_description=readme,
    author='Rafael Alves Ribeiro',
    author_email='rafael.alves.ribeiro@gmail.com',
    url='https://github.com/rafpyprog/pySGS',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Scientific/Engineering :: Information Analysis',
    ],
)
